@@ -42,6 +42,9 @@ class LIFOCache:
                     self.list.deleteNode(self.list.head)
                     self.map[key]=self.list.addToHead(key,value)
             self.verdata.set_data(key,value,self.list.head)
+        
+    def get_info(self):
+        return self.verdata.info()
 
 
 
