@@ -1,11 +1,26 @@
 from cacheall.EvictionPolicies.LRUevictionpolicy import LRUCache
 from cacheall.EvictionPolicies.LIFOevictionpolicy import LIFOCache
 from cacheall.EvictionPolicies.FIFOevictionpolicy import FIFOCache
+from dictionary import dict
 import threading
 import time
 
 lock=threading.Lock()
-dict={0:FIFOCache,1:LRUCache,2:LIFOCache}
+
+
+# import json
+
+
+# with open('dictionary.txt') as f:
+# 	data = f.read()
+
+# print("Data type before reconstruction : ", type(data))
+	
+
+# dict = json.loads(data)
+
+
+# dict={0:FIFOCache,1:LRUCache,2:LIFOCache}
 def cache_dec(size,eviction,verbose=0):
     cache=dict[eviction](size,lock,verbose)
     def decorator(func):
@@ -27,7 +42,7 @@ def cache_dec(size,eviction,verbose=0):
                 k=cache.get(s)
             
             return k
- 
+        
         return inner1
-
+   
     return decorator
\ No newline at end of file
